@@ -15,7 +15,7 @@
 from datetime import datetime
 
 from cinderclient.tests.unit import fakes
-from cinderclient.tests.unit.v2 import fakes as fake_v2
+from cinderclient.tests.unit.v3 import fakes_base
 from cinderclient.v3 import client
 
 
@@ -29,6 +29,16 @@ fake_attachment = {'attachment': {
     'instance': 'e84fda45-4de4-4ce4-8f39-fc9d3b0aa05e',
     'volume_id': '557ad76c-ce54-40a3-9e91-c40d21665cc3', }}
 
+fake_attachment_without_instance_id = {'attachment': {
+    'status': 'reserved',
+    'detached_at': '',
+    'connection_info': {},
+    'attached_at': '',
+    'attach_mode': None,
+    'id': 'a232e9ae',
+    'instance': None,
+    'volume_id': '557ad76c-ce54-40a3-9e91-c40d21665cc3', }}
+
 fake_attachment_list = {'attachments': [
     {'instance': 'instance_1',
      'name': 'attachment-1',
@@ -133,7 +143,7 @@ class FakeClient(fakes.FakeClient, client.Client):
         return self.client.get_volume_api_version_from_endpoint()
 
 
-class FakeHTTPClient(fake_v2.FakeHTTPClient):
+class FakeHTTPClient(fakes_base.FakeHTTPClient):
 
     def __init__(self, **kwargs):
         super(FakeHTTPClient, self).__init__()
@@ -194,6 +204,19 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
                     del svc['backend_state']
         return (200, {}, {'services': services})
 
+    def put_os_services_enable(self, body, **kw):
+        return (200, {}, {'host': body['host'], 'binary': body['binary'],
+                'status': 'enabled'})
+
+    def put_os_services_disable(self, body, **kw):
+        return (200, {}, {'host': body['host'], 'binary': body['binary'],
+                'status': 'disabled'})
+
+    def put_os_services_disable_log_reason(self, body, **kw):
+        return (200, {}, {'host': body['host'], 'binary': body['binary'],
+                'status': 'disabled',
+                'disabled_reason': body['disabled_reason']})
+
     #
     # Clusters
     #
@@ -285,7 +308,7 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
     # Backups
     #
     def put_backups_1234(self, **kw):
-        backup = fake_v2._stub_backup(
+        backup = fakes_base._stub_backup(
             id='1234',
             base_uri='http://localhost:8776',
             tenant_id='0fa851f6668144cf9cd8c8419c1646c1')
@@ -297,7 +320,9 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
     #
 
     def post_attachments(self, **kw):
-        return (200, {}, fake_attachment)
+        if kw['body']['attachment'].get('instance_uuid'):
+            return (200, {}, fake_attachment)
+        return (200, {}, fake_attachment_without_instance_id)
 
     def get_attachments(self, **kw):
         return (200, {}, fake_attachment_list)
@@ -640,10 +665,10 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
         transfer2 = 'f625ec3e-13dd-4498-a22a-50afd534cc41'
         return (200, {},
                 {'transfers': [
-                    fake_v2._stub_transfer_full(transfer1, base_uri,
-                                                tenant_id),
-                    fake_v2._stub_transfer_full(transfer2, base_uri,
-                                                tenant_id)]})
+                    fakes_base._stub_transfer_full(transfer1, base_uri,
+                                                   tenant_id),
+                    fakes_base._stub_transfer_full(transfer2, base_uri,
+                                                   tenant_id)]})
 
     def get_volume_transfers_5678(self, **kw):
         base_uri = 'http://localhost:8776'
@@ -651,7 +676,8 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
         transfer1 = '5678'
         return (200, {},
                 {'transfer':
-                 fake_v2._stub_transfer_full(transfer1, base_uri, tenant_id)})
+                 fakes_base._stub_transfer_full(transfer1, base_uri,
+                                                tenant_id)})
 
     def delete_volume_transfers_5678(self, **kw):
         return (202, {}, None)
@@ -661,16 +687,16 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
         tenant_id = '0fa851f6668144cf9cd8c8419c1646c1'
         transfer1 = '5678'
         return (202, {},
-                {'transfer': fake_v2._stub_transfer(transfer1, base_uri,
-                                                    tenant_id)})
+                {'transfer': fakes_base._stub_transfer(transfer1, base_uri,
+                                                       tenant_id)})
 
     def post_volume_transfers_5678_accept(self, **kw):
         base_uri = 'http://localhost:8776'
         tenant_id = '0fa851f6668144cf9cd8c8419c1646c1'
         transfer1 = '5678'
         return (200, {},
-                {'transfer': fake_v2._stub_transfer(transfer1, base_uri,
-                                                    tenant_id)})
+                {'transfer': fakes_base._stub_transfer(transfer1, base_uri,
+                                                       tenant_id)})
 
 
 def fake_request_get():
