@@ -388,6 +388,25 @@ class ShellTest(utils.TestCase):
               {'cmd': 'abc 1233',
                'body': {'instance_uuid': '1233',
                         'connector': {},
+                        'volume_uuid': '1234'}},
+              {'cmd': '1234',
+               'body': {'connector': {},
+                        'volume_uuid': '1234'}},
+              {'cmd': '1234 '
+                      '--connect True '
+                      '--ip 10.23.12.23 --host server01 '
+                      '--platform x86_xx '
+                      '--ostype 123 '
+                      '--multipath true '
+                      '--mountpoint /123 '
+                      '--initiator aabbccdd',
+               'body': {'connector': {'ip': '10.23.12.23',
+                                      'host': 'server01',
+                                      'os_type': '123',
+                                      'multipath': 'true',
+                                      'mountpoint': '/123',
+                                      'initiator': 'aabbccdd',
+                                      'platform': 'x86_xx'},
                         'volume_uuid': '1234'}})
     @mock.patch('cinderclient.utils.find_resource')
     @ddt.unpack
@@ -429,6 +448,27 @@ class ShellTest(utils.TestCase):
                'body': {'instance_uuid': '1233',
                         'connector': {},
                         'volume_uuid': '1234',
+                        'mode': 'ro'}},
+              {'cmd': '1234',
+               'body': {'connector': {},
+                        'volume_uuid': '1234',
+                        'mode': 'ro'}},
+              {'cmd': '1234 '
+                      '--connect True '
+                      '--ip 10.23.12.23 --host server01 '
+                      '--platform x86_xx '
+                      '--ostype 123 '
+                      '--multipath true '
+                      '--mountpoint /123 '
+                      '--initiator aabbccdd',
+               'body': {'connector': {'ip': '10.23.12.23',
+                                      'host': 'server01',
+                                      'os_type': '123',
+                                      'multipath': 'true',
+                                      'mountpoint': '/123',
+                                      'initiator': 'aabbccdd',
+                                      'platform': 'x86_xx'},
+                        'volume_uuid': '1234',
                         'mode': 'ro'}})
     @mock.patch('cinderclient.utils.find_resource')
     @ddt.unpack
@@ -860,6 +900,67 @@ class ShellTest(utils.TestCase):
                          'manageable-list --cluster dest')
         self.assert_called('GET', '/manageable_volumes/detail?cluster=dest')
 
+    @ddt.data(True, False, 'Nonboolean')
+    @mock.patch('cinderclient.utils.find_resource')
+    def test_snapshot_create_pre_3_66(self, force_value, mock_find_vol):
+        mock_find_vol.return_value = volumes.Volume(
+            self, {'id': '123456'}, loaded=True)
+        snap_body_3_65 = {
+            'snapshot': {
+                'volume_id': '123456',
+                'force': f'{force_value}',
+                'name': None,
+                'description': None,
+                'metadata': {}
+            }
+        }
+        self.run_command('--os-volume-api-version 3.65 '
+                         f'snapshot-create --force {force_value} 123456')
+        self.assert_called_anytime('POST', '/snapshots', body=snap_body_3_65)
+
+    SNAP_BODY_3_66 = {
+        'snapshot': {
+            'volume_id': '123456',
+            'name': None,
+            'description': None,
+            'metadata': {}
+        }
+    }
+
+    @ddt.data(True, 'true', 'on', '1')
+    @mock.patch('cinderclient.utils.find_resource')
+    def test_snapshot_create_3_66_with_force_true(self, f_val, mock_find_vol):
+        mock_find_vol.return_value = volumes.Volume(
+            self, {'id': '123456'}, loaded=True)
+        mock_find_vol.return_value = volumes.Volume(self,
+                                                    {'id': '123456'},
+                                                    loaded=True)
+        self.run_command('--os-volume-api-version 3.66 '
+                         f'snapshot-create --force {f_val} 123456')
+        self.assert_called_anytime('POST', '/snapshots',
+                                   body=self.SNAP_BODY_3_66)
+
+    @ddt.data(False, 'false', 'no', '0', 'whatever')
+    @mock.patch('cinderclient.utils.find_resource')
+    def test_snapshot_create_3_66_with_force_not_true(
+            self, f_val, mock_find_vol):
+        mock_find_vol.return_value = volumes.Volume(
+            self, {'id': '123456'}, loaded=True)
+        uae = self.assertRaises(exceptions.UnsupportedAttribute,
+                                self.run_command,
+                                '--os-volume-api-version 3.66 '
+                                f'snapshot-create --force {f_val} 123456')
+        self.assertIn('not allowed after microversion 3.65', str(uae))
+
+    @mock.patch('cinderclient.utils.find_resource')
+    def test_snapshot_create_3_66(self, mock_find_vol):
+        mock_find_vol.return_value = volumes.Volume(
+            self, {'id': '123456'}, loaded=True)
+        self.run_command('--os-volume-api-version 3.66 '
+                         'snapshot-create 123456')
+        self.assert_called_anytime('POST', '/snapshots',
+                                   body=self.SNAP_BODY_3_66)
+
     def test_snapshot_manageable_list(self):
         self.run_command('--os-volume-api-version 3.8 '
                          'snapshot-manageable-list fakehost')
@@ -1278,12 +1379,14 @@ class ShellTest(utils.TestCase):
         self.assert_called('POST', '/backups', body=expected)
 
     @mock.patch("cinderclient.utils.print_list")
-    def test_snapshot_list_with_userid(self, mock_print_list):
-        """Ensure 3.41 provides User ID header."""
-        self.run_command('--os-volume-api-version 3.41 snapshot-list')
+    def test_snapshot_list(self, mock_print_list):
+        """Ensure we always present all existing fields when listing snaps."""
+        self.run_command('--os-volume-api-version 3.65 snapshot-list')
         self.assert_called('GET', '/snapshots/detail')
-        columns = ['ID', 'Volume ID', 'Status', 'Name', 'Size', 'User ID']
+        columns = ['ID', 'Volume ID', 'Status', 'Name', 'Size',
+                   'Consumes Quota', 'User ID']
         mock_print_list.assert_called_once_with(mock.ANY, columns,
+                                                exclude_unavailable=True,
                                                 sortby_index=0)
 
     @mock.patch('cinderclient.v3.volumes.Volume.migrate_volume')
@@ -1745,7 +1848,7 @@ class ShellTest(utils.TestCase):
     )
     @ddt.unpack
     @mock.patch('cinderclient.utils.print_dict')
-    @mock.patch('cinderclient.tests.unit.v2.fakes._stub_restore')
+    @mock.patch('cinderclient.tests.unit.v3.fakes_base._stub_restore')
     def test_do_backup_restore(self,
                                mock_stub_restore,
                                mock_print_dict,
