@@ -87,6 +87,25 @@ class VolumesTest(utils.TestCase):
         cs.assert_called('POST', '/volumes', body=expected)
         self._assert_request_id(vol)
 
+    def test_create_volume_with_hint(self):
+        cs = fakes.FakeClient(api_versions.APIVersion('3.0'))
+        vol = cs.volumes.create(1, scheduler_hints='uuid')
+        expected = {'volume': {'description': None,
+                               'availability_zone': None,
+                               'source_volid': None,
+                               'snapshot_id': None,
+                               'size': 1,
+                               'name': None,
+                               'imageRef': None,
+                               'volume_type': None,
+                               'metadata': {},
+                               'consistencygroup_id': None,
+                               'backup_id': None,
+                               },
+                    'OS-SCH-HNT:scheduler_hints': 'uuid'}
+        cs.assert_called('POST', '/volumes', body=expected)
+        self._assert_request_id(vol)
+
     @ddt.data((False, '/volumes/summary'),
               (True, '/volumes/summary?all_tenants=True'))
     def test_volume_summary(self, all_tenants_input):
